diff src/protocols/gg/libgg.c @ 5681:46d7ad0dfa26

[gaim-migrate @ 6100] Rewrote the proxy code. It should now work with the new prefs, and it has a namespace and API too! committer: Tailor Script <tailor@pidgin.im>
author Christian Hammond <chipx86@chipx86.com>
date Tue, 03 Jun 2003 02:00:33 +0000
parents cddb50734169
children 059d95c67cda
line wrap: on
line diff
--- a/src/protocols/gg/libgg.c	Mon Jun 02 22:30:25 2003 +0000
+++ b/src/protocols/gg/libgg.c	Tue Jun 03 02:00:33 2003 +0000
@@ -1,4 +1,4 @@
-/* $Id: libgg.c 4552 2003-01-11 19:59:27Z seanegan $ */
+/* $Id: libgg.c 6100 2003-06-03 02:00:33Z chipx86 $ */
 
 /*
  *  (C) Copyright 2001 Wojtek Kaniewski <wojtekka@irc.pl>,
@@ -72,7 +72,7 @@
 #ifdef __GNUC__
 __attribute__ ((unused))
 #endif
-= "$Id: libgg.c 4552 2003-01-11 19:59:27Z seanegan $";
+= "$Id: libgg.c 6100 2003-06-03 02:00:33Z chipx86 $";
 
 #endif 
 
@@ -861,7 +861,7 @@
 	switch (sess->state) {
 #ifndef _WIN32
 		/* Apparantly we will never be in this state as long as we are
-		   using proxy_connect instead of gg_login - Herman */
+		   using gaim_proxy_connect instead of gg_login - Herman */
 		case GG_STATE_RESOLVING:
 		{
 			struct in_addr a;
@@ -1048,7 +1048,7 @@
 			a.s_addr = inet_addr(host);
 			sess->server_ip = a.s_addr;
 #if 0
 			/* We need to watch this non-blocking socket so lets use proxy_connect 
 			   in gg.c - Herman */
 			if((sess->fd = gg_connect(&a, port, sess->assync)) == -1) {
 				gg_debug(GG_DEBUG_MISC, "-- connection failed, trying https connection\n");
@@ -1048,7 +1048,7 @@
 			sess->server_ip = a.s_addr;
 #if 0
-			/* We need to watch this non-blocking socket so lets use proxy_connect 
+			/* We need to watch this non-blocking socket so lets use gaim_proxy_connect 
 			   in gg.c - Herman */
 			if((sess->fd = gg_connect(&a, port, sess->assync)) == -1) {